@@ -14,8 +14,12 @@ def server_status(connection):
     try:
         response = connection.session.get(url=connection.base_url + '/api/status')
     except SSLError:
-        exception_handler("SSL certificate error, if you are using a self-signed certificate, copy your SSL certificate to your working directory or pass the path to the certificate to your Connection. \nOtherwise please double check that the link you are using comes from a trusted source.\n\nCheck readme for more details.",  # noqa
-                          SSLError)
+        exception_handler(
+            ("SSL certificate error.\nPlease double check that the link you "
+             "are using comes from a trusted source. If you trust the URL "
+             "provided please specify parameter 'ssl_verify' to 'False' in the "
+             "'Connection' class.\n\nCheck readme for more details."),
+            SSLError)
 
     if not response.ok:
         response_handler(response, "Failed to check server status")
